# Chrome Profile Extractor

##### version : 
    1.0.0

#####  Package
    pip install chrome-profile-extractor

##### package link :

    https://pypi.org/project/chrome-profile-extractor/

##### github link :

    https://github.com/HanZawNyein/chrome-profile-extractor.git

##### Author :

    Han Zaw Nyein

##### Author Email :

    hanzawnyineonline@gmail.com

### Description :
    this package for education purpose only.